import type { InspectRecordVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  inspRecordExport = '/eims/inspRecord/export',
  inspRecordList = '/eims/inspRecord/list',
  inspStRecordList = '/eims/inspRecord/stList',
  root = '/eims/inspRecord'
}

/**
 * 查询点检记录列表
 * @param query
 * @returns {*}
 */

export function listInspRecord(params?: any) {
  return requestClient.get<InspectRecordVO[]>(Api.inspRecordList, { params });
}

/**
 * 查询汇总下的点检记录列表
 * @param query
 * @returns {*}
 */

export function listInspStRecord(params?: any) {
  return requestClient.get<InspectRecordVO[]>(Api.inspStRecordList, { params });
}

/**
 * 查询点检记录详细
 * @param inspRecordId
 */
export function getInspRecord(inspRecordId: ID) {
  return requestClient.get<InspectRecordVO>(`${Api.root}/${inspRecordId}`);
}

/**
 * 新增点检记录
 * @param data
 */
export function addInspRecord(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改点检记录
 * @param data
 */
export function updateInspRecord(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除点检记录
 * @param inspRecordId
 */
export function delInspRecord(inspRecordId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${inspRecordId}`);
}
/**
 * 导出
 * @param
 */
export function inspRecordExport(data: any) {
  return commonExport(Api.inspRecordExport, data);
}
